@@ -23,21 +23,6 @@ setClass("mi",
             contains  = "list"
 )
 
-setClass("mi.glm",
-            representation(
-                call           = "call",
-                mi.pooled  = "list" ,
-                mi.fit     = "list"),
-            contains  = "list"
-)
-
-setClass("mi.mer",
-            representation(
-                call         = "call",
-                mi.pooled = "list" ,
-                mi.fit    = "list"),
-            contains  = "list"
-)
 
 
 
@@ -59,15 +44,6 @@ setClass("mi.mer",
 
 
 
-setClass("mi.lm",
-            representation(
-                call          = "call",
-                mi.pooled  = "list" ,
-                mi.fit     = "list"),
-                contains      = "list"
-)
-
-
 setClass("mi.method",
         representation(
           model     = "list",
@@ -146,3 +122,12 @@ setClass("mi.copy",
             random   = "ANY"),
             contains = "mi.method"
 )
+
+
+setClass("mi.pooled",
+            representation(
+                call       = "call",
+                mi.pooled  = "list" ,
+                mi.fit     = "list"),
+                contains   = "list"
+)
